import { css, cx } from "@linaria/core";
import { defineComponent } from "vue";
import { bool, string } from "vue-types";
import { useEditor } from "../../../..";
import { DesignComp } from "../../../../objects/DesignTemp/DesignComp";
import { formatColor } from "../../formItems/NewColorPicker/ColorList";
import { View } from "../View";
import { CompUI } from "../..";
import { useCompData } from "../../defines/hook";
import { CompCardObj } from ".";

export const Component = defineComponent({
  props: {
    compId: string().isRequired,
    showMask: bool().def(false),
  },
  setup(props) {
    const { helper, controls , store} = useEditor();
    const comp = useCompData<CompCardObj>(props.compId);
    const isStreamCard = helper.isStreamCard(props.compId);
    
    const isShowSwiper = () => {
      const { value } = controls.pageCtrl.rootPage;
      return (
        value.pageMode == "short" &&
        // && value.useFor == "pc"
        !store.isEditMode
      );
    };

  
    const getContainerStyles = () => {
      const rootPage = controls.pageCtrl.rootPage;
      const isPcDesign = rootPage.value.useFor == "pc";
      const isShortDesign = rootPage.value.pageMode == "short";

      const style: any = {};
      // 翻页
      if (isStreamCard && isShortDesign && store.isDisplay) {
        if (!isPcDesign) {
          style.height = "100%";
          style.width = "100%";
        } else {
          style.height = "100vh";
          style.width = "100vw";
        }
        // if (isPcDesign) {
        const comp = helper.findComp(props.compId);
        if (!comp) return;
        if (!comp.layout.background) return;
        if (comp.layout.background.color) {
          style.background = formatColor(comp.layout.background.color);
        }
        // }

        style.display = "flex";
        style.justifyContent = "center";
        style.alignItems = "center";
      }
      return style;
    };

    const createScale = () => {
      const showSwiper = isShowSwiper();
      if (!showSwiper) return;
      const scale = controls.previewCtrl.state.scale;
      const style = { transform: `scale(${scale})` };
      return style;
    };

    return () => {
      const showSwiper = isShowSwiper();
      const containerStyles = getContainerStyles();
      const containerScale = createScale();
      
      return (
        <div
          class={cx(rootStyles, showSwiper && "swiper-slide")}
          style={containerStyles}
        >
          <View
            compId={props.compId}
            style={containerScale}
            showMask={props.showMask}
          >
            {comp.children.default?.map((compId) => {
              const compItem = helper.findComp(compId) as DesignComp;
              const Comp =
                controls.compUICtrl.state.components.get(compItem?.compKey)
                  ?.Component || CompUI.Container.Component;

              return <Comp key={compItem.id} compId={compItem.id} />;
            })}
          </View>
        </div>
      );
    };
  },
});

const rootStyles = css`
  &.swiper-slide {
    > div {
      background: none !important;
    }
  }
  &.swiper-slide-active {
    z-index: 10;
  }
`;
